@@ -1,10 +1,9 @@
-import sys, getopt
-
-sys.path.insert(1, "rollo/")
 from rollo import executor
-from deap import creator, base
+import sys
+import getopt
 
-if __name__ == "__main__":
+
+def main():
     argv = sys.argv[1:]
     msg = "python rollo -i <inputfile> -c <checkpoint file> "
     try:
@@ -20,5 +19,11 @@ if __name__ == "__main__":
             else:
                 new_run = executor.Executor(input_file=opts_dict["-i"])
             new_run.execute()
+        if len(opts) == 0:
+            raise Exception("To run rollo: " + msg)
     except getopt.GetoptError:
         raise Exception("To run rollo: " + msg)
+
+
+if __name__ == "__main__":
+    main()
