@@ -16,8 +16,9 @@ class InputValidation:
     def __init__(self, input_dict):
         self.input = input_dict
 
-    def add_defaults(self, input_dict):
-        """Adds default inputs if they are missing from the input_dict
+    def add_all_defaults(self, input_dict):
+        """ Goes through the entire input_dict and adds default inputs if they 
+        are missing from the input_dict
 
         Parameters
         ----------
@@ -41,7 +42,7 @@ class InputValidation:
         input_algorithm = self.default_check(input_algorithm, "pop_size", 100)
         input_algorithm = self.default_check(input_algorithm, "generations", 10)
         input_algorithm = self.default_check(
-            input_algorithm, "selection_operator", {"operator": "selBest", "k": 1}
+            input_algorithm, "selection_operator", {"operator": "selBest", "inds": 1}
         )
         input_algorithm = self.default_check(
             input_algorithm,
@@ -57,8 +58,8 @@ class InputValidation:
         return reloaded_input_dict
 
     def default_check(self, input_dict, variable, default_val):
-        """Checks if a variable is missing from a dict, and adds a default
-        value if it is
+        """Checks if a single variable is missing from a dict, and adds a 
+        default value if it is
 
         Parameters
         ----------
@@ -213,12 +214,15 @@ class InputValidation:
 
         # k value cannot be larger than pop size
         if input_algorithm["selection_operator"]["operator"] == "selTournament":
-            if input_algorithm["selection_operator"]["k"] > input_algorithm["pop_size"]:
-                raise Exception("Population size must be larger than k.")
+            if (
+                input_algorithm["selection_operator"]["inds"] >
+                input_algorithm["pop_size"]
+            ):
+                raise Exception("Population size must be larger than inds.")
         return
 
     def validate_algorithm_operators(self, operator_type, input_algorithm):
-        """Validates the DEAP operators
+        """Validates the genetic algorithm operators
 
         Parameters
         ----------
@@ -231,9 +235,9 @@ class InputValidation:
 
         deap_operators = {
             "selection": {
-                "selTournament": ["k", "tournsize"],
-                "selNSGA2": ["k"],
-                "selBest": ["k"],
+                "selTournament": ["inds", "tournsize"],
+                "selNSGA2": ["inds"],
+                "selBest": ["inds"],
             },
             "mutation": {
                 "mutPolynomialBounded": ["eta", "indpb"],
@@ -251,9 +255,9 @@ class InputValidation:
                 op_op = op["operator"]
             except KeyError:
                 print(
-                    "<Input Validation Error> You must define an operator for the "
-                    + operator_type
-                    + "_operator"
+                    "<Input Validation Error> You must define an operator for the " +
+                    operator_type +
+                    "_operator"
                 )
                 raise
             else:
@@ -455,11 +459,11 @@ class InputValidation:
                     a = input_evaluators[evaluator]["output_script"]
                 except KeyError:
                     print(
-                        "<Input Validation Error> You must define an output_script for evaluator: "
-                        + evaluator
-                        + " since the outputs: "
-                        + str(which_strings)
-                        + " are not inputs or pre-defined outputs."
+                        "<Input Validation Error> You must define an output_script for evaluator: " +
+                        evaluator +
+                        " since the outputs: " +
+                        str(which_strings) +
+                        " are not inputs or pre-defined outputs."
                     )
                     raise
         return
@@ -505,12 +509,12 @@ class InputValidation:
 
         """
         assert variable in accepted_variables, (
-            "<Input Validation Error> variable: "
-            + name
-            + ", only accepts: "
-            + str(accepted_variables)
-            + " not variable: "
-            + variable
+            "<Input Validation Error> variable: " +
+            name +
+            ", only accepts: " +
+            str(accepted_variables) +
+            " not variable: " +
+            variable
         )
         return
 
@@ -538,19 +542,19 @@ class InputValidation:
                 a = dict_to_validate[key]
             for key in dict_to_validate:
                 assert key in combined_key_names, (
-                    "<Input Validation Error> Only "
-                    + str(combined_key_names)
-                    + " are accepted for "
-                    + variable_type
-                    + ", not variable: "
-                    + key
+                    "<Input Validation Error> Only " +
+                    str(combined_key_names) +
+                    " are accepted for " +
+                    variable_type +
+                    ", not variable: " +
+                    key
                 )
         except KeyError:
             print(
-                "<Input Validation Error> "
-                + str(key_names)
-                + " variables must be defined for "
-                + variable_type
+                "<Input Validation Error> " +
+                str(key_names) +
+                " variables must be defined for " +
+                variable_type
             )
             raise
         except AssertionError as error:
